@@ -1,7 +1,7 @@
 package Carmel;
 use strict;
 use 5.010_001;
-use version; our $VERSION = version->declare('v0.1.4');
+use version; our $VERSION = version->declare('v0.1.5');
 
 1;
 __END__
@@ -20,6 +20,15 @@ Carmel - CPAN Artifact Repository Manager
   # Manually pull a module if you don't have it
   carmel install DBI@1.633 Plack@1.0000
 
+  # list all the modules to be loaded
+  carmel list
+
+  # list all the modules in a tree
+  carmel tree
+
+  # show a location where a module is installed
+  carmel show Plack
+
   # Runs your perl script with modules from artifacts
   carmel exec perl ...
 
@@ -29,14 +38,12 @@ Carmel - CPAN Artifact Repository Manager
   # prints export PERL5LIB=... etc for shell scripting
   carmel export
 
-  # find a module in repository
+  # find a module in a repository
   carmel find DBI
 
   # find a module matching the version query
   carmel find Plack ">= 1.0000, < 1.1000"
 
-  # list all the modules to be loaded
-  carmel list
 
 =head1 DESCRIPTION
 
@@ -116,8 +123,4 @@ it under the same terms as Perl itself.
 
 L<App::cpanminus> L<Carton>
 
-https://github.com/ingydotnet/only-pm
-
-https://github.com/gugod/perlrocks
-
 =cut
