@@ -4,40 +4,59 @@ use version ();
 use DirHandle;
 use Carmel::Artifact;
 use CPAN::Meta::Requirements;
+use File::Copy::Recursive ();
 use JSON ();
 
 sub new {
-    my $class = shift;
-    bless {}, $class;
+    my($class, $path) = @_;
+    my $self = bless {
+        path => Path::Tiny->new($path),
+    }, $class;
+    $self->load_artifacts;
+    $self;
+}
+
+sub path { $_[0]->{path} }
+
+sub import_artifact {
+    my($self, $dir) = @_;
+
+    my $dest = $self->path->child($dir->basename);
+    File::Copy::Recursive::dircopy($dir, $dest);
+
+    $self->load($dest);
 }
 
 sub read_json {
     my $file = shift;
-    open my $fh, "<", $file or die "$file: $!";
-    JSON::decode_json(join '', <$fh>);
+    JSON::decode_json($file->slurp);
+}
+
+sub load_artifacts {
+    my $self = shift;
+    $self->path->mkpath unless $self->path->exists;
+
+    for my $ent ($self->path->children) {
+        if ($ent->is_dir && $ent->child("blib")->exists) {
+            $self->load($ent);
+        }
+    }
 }
 
 sub load {
     my($self, $dir) = @_;
 
-    my $dh = DirHandle->new($dir) or return;
-    while (my $ent = $dh->read) {
-        next unless -d "$dir/$ent" && -e "$dir/$ent/blib";
-
-        my $install = $self->_install_info("$dir/$ent");
-        while (my($package, $data) = each %{ $install->{provides} }) {
-            $self->add($package, "$dir/$ent", $data->{version}, $install);
-        }
+    my $install = $self->_install_info($dir);
+    while (my($package, $data) = each %{ $install->{provides} }) {
+        $self->add($package, $dir, $data->{version}, $install);
     }
 }
 
 sub _install_info {
     my($self, $dir) = @_;
 
-    my $file = "$dir/blib/meta/install.json";
-
-    # cpanm build artifact
-    if (-e $file) {
+    my $file = $dir->child("blib/meta/install.json");
+    if ($file->exists) {
         return read_json($file);
     }
 
